@@ -4,5 +4,10 @@ from .pairwise import (  # noqa
     pairwise_distances,
     pairwise_distances_argmin_min,
 )
-from .regression import mean_absolute_error, mean_squared_error, r2_score  # noqa
+from .regression import (  # noqa
+    mean_absolute_error,
+    mean_squared_error,
+    mean_squared_log_error,
+    r2_score,
+)
 from .scorer import SCORERS, check_scoring, get_scorer  # noqa
