@@ -6,6 +6,7 @@ import numpy as np
 import pandas as pd
 import sklearn.preprocessing
 
+from .._compat import SK_024
 from .._typing import ArrayLike, DataFrameType, SeriesType
 from ..utils import check_array
 from .label import _encode, _encode_dask_array
@@ -154,12 +155,23 @@ class OneHotEncoder(sklearn.preprocessing.OneHotEncoder):
 
         return self
 
-    def _fit(self, X: Union[ArrayLike, DataFrameType], handle_unknown: str = "error"):
+    def _fit(
+        self,
+        X: Union[ArrayLike, DataFrameType],
+        handle_unknown: str = "error",
+        force_all_finite: bool = True,
+    ):
         X = check_array(
             X, accept_dask_dataframe=True, dtype=None, preserve_pandas_dataframe=True
         )
+        if SK_024:
+            kwargs = dict(force_all_finite=force_all_finite)
+        else:
+            kwargs = {}
         if isinstance(X, np.ndarray):
-            return super(OneHotEncoder, self)._fit(X, handle_unknown=handle_unknown)
+            return super(OneHotEncoder, self)._fit(
+                X, handle_unknown=handle_unknown, **kwargs
+            )
 
         is_array = isinstance(X, da.Array)
 
@@ -191,19 +203,21 @@ class OneHotEncoder(sklearn.preprocessing.OneHotEncoder):
                 self.categories_.append(cats)
                 self.dtypes_.append(None)
         else:
-            if not (X.dtypes == "category").all():
-                raise ValueError("All columns must be Categorical dtype.")
-            if self.categories == "auto":
-                for col in X.columns:
-                    Xi = X[col]
-                    cats = _encode(Xi, uniques=Xi.cat.categories)
-                    self.categories_.append(cats)
-                    self.dtypes_.append(Xi.dtype)
-            else:
-                raise ValueError(
-                    "Cannot specify 'categories' with DataFrame input. "
-                    "Use a categorical dtype instead."
-                )
+            for i in range(len(X.columns)):
+                Xi = X.iloc[:, i]
+                if self.categories != "auto":
+                    categories = self.categories[i]
+                    Xi = Xi.astype(pd.CategoricalDtype(categories))
+                else:
+                    if not pd.api.types.is_categorical_dtype(Xi.dtype):
+                        raise ValueError(
+                            "All columns must be Categorical dtype when "
+                            "'categories=\"auto\"'."
+                        )
+
+                cats = _encode(Xi, uniques=Xi.cat.categories)
+                self.categories_.append(cats)
+                self.dtypes_.append(Xi.dtype)
 
         self.categories_ = dask.compute(self.categories_)[0]
 
@@ -250,9 +264,7 @@ class OneHotEncoder(sklearn.preprocessing.OneHotEncoder):
         else:
             import dask.dataframe as dd
 
-            # Validate that all are categorical.
-            if not (X.dtypes == "category").all():
-                raise ValueError("Must be all categorical.")
+            X = X.copy()
 
             if not len(X.columns) == len(self.categories_):
                 raise ValueError(
@@ -260,13 +272,17 @@ class OneHotEncoder(sklearn.preprocessing.OneHotEncoder):
                     "of categories_ ({})".format(len(X.columns), len(self.categories_))
                 )
 
-            for col, dtype in zip(X.columns, self.dtypes_):
-                if not (X[col].dtype == dtype):
-                    raise ValueError(
-                        "Different CategoricalDtype for fit and "
-                        "transform. '{}' != {}'".format(dtype, X[col].dtype)
-                    )
+            for i, (col, dtype) in enumerate(zip(X.columns, self.dtypes_)):
+                Xi = X.iloc[:, i]
+                if not pd.api.types.is_categorical_dtype(Xi.dtype):
+                    Xi = Xi.astype(dtype)
+                    X[col] = Xi
 
+                if Xi.dtype != dtype:
+                    raise ValueError(
+                        "Different CategoricalDtype for fit and transform. "
+                        "{!r} != {!r}".format(Xi.dtype, dtype)
+                    )
             return dd.get_dummies(X, sparse=self.sparse, dtype=self.dtype)
 
         return X
