@@ -33,8 +33,8 @@ def _svd_flip_copy(x, y, u_based_decision=True):
         return skm.svd_flip(x.copy(), y.copy(), u_based_decision=u_based_decision)
 
 
-def svd_flip(u, v):
-    u2, v2 = delayed(_svd_flip_copy, nout=2)(u, v)
+def svd_flip(u, v, u_based_decision=True):
+    u2, v2 = delayed(_svd_flip_copy, nout=2)(u, v, u_based_decision=u_based_decision)
     u = da.from_delayed(u2, shape=u.shape, dtype=u.dtype)
     v = da.from_delayed(v2, shape=v.shape, dtype=v.dtype)
     return u, v
@@ -43,6 +43,22 @@ def svd_flip(u, v):
 svd_flip.__doc__ = skm.svd_flip.__doc__
 
 
+def flip_vector_signs(x, axis):
+    """Flip vector signs to align them for comparison
+
+    Parameters
+    ----------
+    x : 2D array_like
+        Matrix containing vectors in rows or columns
+    axis : int, 0 or 1
+        Axis in which vectors reside
+    """
+    assert x.ndim == 2
+    signs = np.sum(x, axis=axis, keepdims=True)
+    signs = signs.dtype.type(2) * ((signs >= 0) - signs.dtype.type(0.5))
+    return x * signs
+
+
 def slice_columns(X, columns):
     if isinstance(X, dd.DataFrame):
         return X[list(X.columns) if columns is None else columns]
@@ -307,7 +323,7 @@ def _log_array(logger, arr, name):
 
 def _format_bytes(n):
     # TODO: just import from distributed if / when required
-    """ Format bytes as text
+    """Format bytes as text
 
     >>> format_bytes(1)
     '1 B'
